@@ -16,6 +16,7 @@ class TestAPTest(unittest.TestCase):
         self.args.sjds = [59011]
         self.args.exps = [[34490027, 34490042, 34490051, 34490056, 34490069]]
         self.args.plot = False
+        self.args.legacy = False
         self.args.verbose = True
         master_path = self.project / 'dat/master_dome_flat_1.npy'
         self.master_data = np.load(master_path)
@@ -37,6 +38,13 @@ class TestAPTest(unittest.TestCase):
         self.atest = ap_test.ApogeeFlat(self.master_data, self.args)
         self.atest.run_inputs()
 
+    def test_legacy(self):
+        """Test the legacy version of ap_test"""
+        self.args.legacy = True
+        self.master_data = np.load(self.project / 'dat/utr_master_flat_21180043.npy')
+        self.atest = ap_test.ApogeeFlat(self.master_data, self.args)
+        self.atest.run_inputs()
+
 
 if __name__ == '__main__':
     unittest.main()
